@@ -1,6 +1,6 @@
 package Sub::Spec::CmdLine;
 BEGIN {
-  $Sub::Spec::CmdLine::VERSION = '0.22';
+  $Sub::Spec::CmdLine::VERSION = '0.23';
 }
 # ABSTRACT: Access Perl subs via command line
 
@@ -75,7 +75,7 @@ sub parse_argv {
         "no_ignore_case", "permute");
     my $result = Getopt::Long::GetOptionsFromArray($argv, %go_spec);
     unless ($result) {
-        die "Incorrect command-line options/arguments\n" if $opts->{strict};
+        die BlankStr->new if $opts->{strict};
     }
 
     #$log->tracef("tmp args result (after getoptions): %s, argv: %s",
@@ -698,6 +698,13 @@ sub run {
     if ($exit) { exit $exit_code } else { return $exit_code }
 }
 
+package BlankStr;
+BEGIN {
+  $BlankStr::VERSION = '0.23';
+}
+use overload q{""} => sub { " \b" };
+sub new { bless(\$_[0], $_[0]) }
+
 1;
 
 
@@ -709,7 +716,7 @@ Sub::Spec::CmdLine - Access Perl subs via command line
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
